@@ -18,12 +18,12 @@ pushd libmosquitto-0.9.1.$SVNVER
 echo y | dh_make --createorig --single -e yuvraaj@gmail.com -c lgpl
 
 # First create everything for libmosquitto
-cp build-files/postinst.libmosquitto debian/postinst
 cp build-files/libmosquitto.control debian/control
 cp build-files/libmosquitto.rules debian/rules
 cp build-files/libmosquitto.install debian/
 dpkg-buildpackage -rfakeroot -sa -S
-dput -f $1-extras-builder ../libmosquitto*.changes
+dput -f $1-extras-builder ./libmosquitto*.changes
+#dpkg-buildpackage -rfakeroot
 
 popd
 
