@@ -18,12 +18,12 @@ pushd libmosquittopp-0.9.1.$SVNVER
 echo y | dh_make --createorig --single -e yuvraaj@gmail.com -c lgpl
 
 # First create everything for libmosquittopp
-cp build-files/postinst.libmosquittopp debian/postinst
 cp build-files/libmosquittopp.control debian/control
 cp build-files/libmosquittopp.rules debian/rules
 cp build-files/libmosquittopp.install debian/
 dpkg-buildpackage -rfakeroot -sa -S
-dput -f $1-extras-builder ../libmosquittopp*.changes
+dput -f $1-extras-builder ./libmosquittopp*.changes
+#dpkg-buildpackage -rfakeroot
 
 popd
 
